Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

AdultContentPref

BskyAppProgressGuide

If set, an active progress guide. Once completed, can be set to undefined. Should have unspecced fields tracking progress.

BskyAppStatePref

A grab bag of state that's specific to the bsky.app program. Third-party apps shouldn't use this.

ContentLabelPref

ContentLabelPrefVisibility

DeclaredAgePref

Read-only preference containing value(s) inferred from the user's declared birthdate. Absence of this preference object in the response indicates that the user has not made a declaration.

FeedViewPref

HiddenPostsPref

InterestsPref

KnownFollowers

The subject's followers whom you also follow

LabelerPrefItem

LabelersPref

LiveEventPreferences

Preferences for live events.

MutedWord

A word that the account owner has muted.

MutedWordActorTarget

MutedWordTarget

MutedWordsPref

Nux

A new user experiences (NUX) storage object

PersonalDetailsPref

PostInteractionSettingsPref

Default post interaction settings for the account. These values should be applied as default values when creating new posts. These refs should mirror the threadgate and postgate records exactly.

PostInteractionSettingsPrefPostgateEmbeddingRulesItem

PostInteractionSettingsPrefThreadgateAllowRulesItem

Preferences

ProfileAssociated

ProfileAssociatedActivitySubscription

ProfileAssociatedActivitySubscriptionAllowSubscriptions

ProfileAssociatedChat

ProfileAssociatedChatAllowIncoming

ProfileAssociatedGerm

ProfileAssociatedGermShowButtonTo

ProfileView

ProfileViewBasic

ProfileViewDetailed

SavedFeed

SavedFeedType

SavedFeedsPref

SavedFeedsPrefV2

StatusView

StatusViewEmbedUnion

An optional embed associated with the status.

StatusViewStatus

ThreadViewPref

ThreadViewPrefSort

VerificationPrefs

Preferences for how verified accounts appear in the app.

VerificationState

Represents the verification information about the user this object is attached to.

VerificationStateTrustedVerifierStatus

VerificationStateVerifiedStatus

VerificationView

An individual verification for an associated subject.

ViewerState

Metadata about the requesting account's relationship with the subject account. Only has meaningful content for authed requests.

Type something to start searching.