Header menu logo FSharp.ATProto

PostInteractionSettingsPref Type

Default post interaction settings for the account. These values should be applied as default values when creating new posts. These refs should mirror the threadgate and postgate records exactly.

Record fields

Record Field Description

PostgateEmbeddingRules

Full Usage: PostgateEmbeddingRules

Field type: PostInteractionSettingsPrefPostgateEmbeddingRulesItem list option

ThreadgateAllowRules

Full Usage: ThreadgateAllowRules

Field type: PostInteractionSettingsPrefThreadgateAllowRulesItem list option

Type something to start searching.