VerificationState Type
Represents the verification information about the user this object is attached to.
Record fields
| Record Field |
Description
|
|
|
|
|
|
|
Represents the verification information about the user this object is attached to.
| Record Field |
Description
|
|
|
|
|
|
|