Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

Access

Config

ConfigRegion

The Age Assurance configuration for a specific region.

ConfigRegionRuleDefault

Age Assurance rule that applies by default.

ConfigRegionRuleIfAccountNewerThan

Age Assurance rule that applies if the account is equal-to or newer than a certain date.

ConfigRegionRuleIfAccountOlderThan

Age Assurance rule that applies if the account is older than a certain date.

ConfigRegionRuleIfAssuredOverAge

Age Assurance rule that applies if the user has been assured to be equal-to or over a certain age.

ConfigRegionRuleIfAssuredUnderAge

Age Assurance rule that applies if the user has been assured to be under a certain age.

ConfigRegionRuleIfDeclaredOverAge

Age Assurance rule that applies if the user has declared themselves equal-to or over a certain age.

ConfigRegionRuleIfDeclaredUnderAge

Age Assurance rule that applies if the user has declared themselves under a certain age.

ConfigRegionRulesItem

Event

Object used to store Age Assurance data in stash.

EventAccess

EventStatus

State

The user's computed Age Assurance state.

StateMetadata

Additional metadata needed to compute Age Assurance state client-side.

Status

Type something to start searching.