ConfigRegionRuleIfAccountOlderThan Type
Age Assurance rule that applies if the account is older than a certain date.
Record fields
| Record Field |
Description
|
|
|
|
|
Age Assurance rule that applies if the account is older than a certain date.
| Record Field |
Description
|
|
|
|
|