Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

MatchAndContactIndex

Associates a profile with the positional index of the contact import input in the call to `app.bsky.contact.importContacts`, so clients can know which phone caused a particular match.

Notification

A stash object to be sent via bsync representing a notification to be created.

SyncStatus

Type something to start searching.