Defs Module
Types
| Type | Description |
|
width:height represents an aspect ratio. It may be approximate, and may not correspond to absolute dimensions in any given unit. |
| Type | Description |
|
width:height represents an aspect ratio. It may be approximate, and may not correspond to absolute dimensions in any given unit. |