Header menu logo FSharp.ATProto

Postgate Module

Types

Type Description

DisableRule

Postgate

Record defining interaction rules for a post. The record key (rkey) of the postgate record must match the record key of the post, and that record must be in the same repository.

PostgateEmbeddingRulesItem

Functions and values

Function or value Description

TypeId

Full Usage: TypeId

Returns: string
Returns: string

Type something to start searching.