Header menu logo FSharp.ATProto

Postgate Type

Record defining interaction rules for a post. The record key (rkey) of the postgate record must match the record key of the post, and that record must be in the same repository.

Record fields

Record Field Description

CreatedAt

Full Usage: CreatedAt

Field type: AtDateTime
Field type: AtDateTime

DetachedEmbeddingUris

Full Usage: DetachedEmbeddingUris

Field type: AtUri list option
Field type: AtUri list option

EmbeddingRules

Full Usage: EmbeddingRules

Field type: PostgateEmbeddingRulesItem list option
Field type: PostgateEmbeddingRulesItem list option

Post

Full Usage: Post

Field type: AtUri
Field type: AtUri

Type something to start searching.