Header menu logo FSharp.ATProto

Threadgate Module

Types

Type Description

FollowerRule

FollowingRule

ListRule

Allow replies from actors on a list.

MentionRule

Threadgate

Record defining interaction gating rules for a thread (aka, reply controls). The record key (rkey) of the threadgate record must match the record key of the thread's root post, and that record must be in the same repository.

ThreadgateAllowItem

Functions and values

Function or value Description

TypeId

Full Usage: TypeId

Returns: string
Returns: string

Type something to start searching.