Header menu logo FSharp.ATProto

Threadgate Type

Record defining interaction gating rules for a thread (aka, reply controls). The record key (rkey) of the threadgate record must match the record key of the thread's root post, and that record must be in the same repository.

Record fields

Record Field Description

Allow

Full Usage: Allow

Field type: ThreadgateAllowItem list option
Field type: ThreadgateAllowItem list option

CreatedAt

Full Usage: CreatedAt

Field type: AtDateTime
Field type: AtDateTime

HiddenReplies

Full Usage: HiddenReplies

Field type: AtUri list option
Field type: AtUri list option

Post

Full Usage: Post

Field type: AtUri
Field type: AtUri

Type something to start searching.