ListWithMembership Type
A list and an optional list item indicating membership of a target user to that list.
Record fields
| Record Field |
Description
|
|
|
|
|
A list and an optional list item indicating membership of a target user to that list.
| Record Field |
Description
|
|
|
|
|