GetStarterPacksWithMembership Module
Types
| Type | Description |
|
|
|
|
|
|
|
A starter pack and an optional list item indicating membership of a target user to that starter pack. |
Functions and values
| Function or value |
Description
|
Full Usage:
TypeId
Returns: string
|
|