Header menu logo FSharp.ATProto

StarterPackWithMembership Type

A starter pack and an optional list item indicating membership of a target user to that starter pack.

Record fields

Record Field Description

ListItem

Full Usage: ListItem

Field type: ListItemView option
Field type: ListItemView option

StarterPack

Full Usage: StarterPack

Field type: StarterPackView
Field type: StarterPackView

Type something to start searching.