Header menu logo FSharp.ATProto

Verification Module

Types

Type Description

Verification

Record declaring a verification relationship between two accounts. Verifications are only considered valid by an app if issued by an account the app considers trusted.

Functions and values

Function or value Description

TypeId

Full Usage: TypeId

Returns: string
Returns: string

Type something to start searching.