Verification Type
Record declaring a verification relationship between two accounts. Verifications are only considered valid by an app if issued by an account the app considers trusted.
Record fields
| Record Field |
Description
|
|
|
Full Usage:
DisplayName
Field type: string
|
|
|
|
|