Header menu logo FSharp.ATProto

Facet Module

Types

Type Description

ByteSlice

Specifies the sub-string range a facet feature applies to. Start index is inclusive, end index is exclusive. Indices are zero-indexed, counting bytes of the UTF-8 encoded text. NOTE: some languages, like Javascript, use UTF-16 or Unicode codepoints for string slice indexing; in these languages, convert to byte arrays before working with facets.

Facet

Annotation of a sub-string within rich text.

FacetFeaturesItem

Link

Facet feature for a URL. The text URL may have been simplified or truncated, but the facet reference should be a complete URL.

Mention

Facet feature for mention of another account. The text is usually a handle, including a '@' prefix, but the facet reference is a DID.

Tag

Facet feature for a hashtag. The text usually includes a '#' prefix, but the facet reference should not (except in the case of 'double hash tags').

Type something to start searching.