Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

AgeAssuranceEvent

Object used to store age assurance data in stash.

AgeAssuranceEventStatus

AgeAssuranceState

The computed state of the age assurance process, returned to the user in question on certain authenticated requests.

AgeAssuranceStateStatus

SkeletonSearchActor

SkeletonSearchPost

SkeletonSearchStarterPack

SkeletonTrend

SkeletonTrendStatus

ThreadItemBlocked

ThreadItemNoUnauthenticated

ThreadItemNotFound

ThreadItemPost

TrendView

TrendViewStatus

TrendingTopic

Type something to start searching.