Header menu logo FSharp.ATProto

AgeAssuranceState Type

The computed state of the age assurance process, returned to the user in question on certain authenticated requests.

Record fields

Record Field Description

LastInitiatedAt

Full Usage: LastInitiatedAt

Field type: AtDateTime option
Field type: AtDateTime option

Status

Full Usage: Status

Field type: AgeAssuranceStateStatus

Type something to start searching.