Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

Label

Metadata tag on an atproto resource (eg, repo or record).

LabelValue

LabelValueDefinition

Declares a label value and its expected interpretations and behaviors.

LabelValueDefinitionBlurs

LabelValueDefinitionDefaultSetting

LabelValueDefinitionSeverity

LabelValueDefinitionStrings

Strings which describe the label in the UI, localized into a specific language.

SelfLabel

Metadata tag on an atproto record, published by the author within the record. Note that schemas should use #selfLabels, not #selfLabel.

SelfLabels

Metadata tags on an atproto record, published by the author within the record.

Type something to start searching.