Header menu logo FSharp.ATProto

Account Type

Represents a change to an account's status on a host (eg, PDS or Relay). The semantics of this event are that the status is at the host which emitted the event, not necessarily that at the currently active PDS. Eg, a Relay takedown would emit a takedown with active=false, even if the PDS is still active.

Record fields

Record Field Description

Active

Full Usage: Active

Field type: bool
Field type: bool

Did

Full Usage: Did

Field type: Did
Field type: Did

Seq

Full Usage: Seq

Field type: int64
Field type: int64

Status

Full Usage: Status

Field type: AccountStatus option
Field type: AccountStatus option

Time

Full Usage: Time

Field type: AtDateTime
Field type: AtDateTime

Type something to start searching.