Header menu logo FSharp.ATProto

Commit Type

Represents an update of repository state. Note that empty commits are allowed, which include no repo data changes, but an update to rev and signature.

Record fields

Record Field Description

Blobs

Full Usage: Blobs

Field type: Cid list
Field type: Cid list

Blocks

Full Usage: Blocks

Field type: byte[]
Field type: byte[]

Commit

Full Usage: Commit

Field type: Cid
Field type: Cid

Ops

Full Usage: Ops

Field type: RepoOp list
Field type: RepoOp list

PrevData

Full Usage: PrevData

Field type: Cid option
Field type: Cid option

Rebase

Full Usage: Rebase

Field type: bool
Field type: bool

Repo

Full Usage: Repo

Field type: Did
Field type: Did

Rev

Full Usage: Rev

Field type: Tid
Field type: Tid

Seq

Full Usage: Seq

Field type: int64
Field type: int64

Since

Full Usage: Since

Field type: Tid option
Field type: Tid option

Time

Full Usage: Time

Field type: AtDateTime
Field type: AtDateTime

TooBig

Full Usage: TooBig

Field type: bool
Field type: bool

Type something to start searching.