Header menu logo FSharp.ATProto

Identity Type

Represents a change to an account's identity. Could be an updated handle, signing key, or pds hosting endpoint. Serves as a prod to all downstream services to refresh their identity cache.

Record fields

Record Field Description

Did

Full Usage: Did

Field type: Did
Field type: Did

Handle

Full Usage: Handle

Field type: Handle option
Field type: Handle option

Seq

Full Usage: Seq

Field type: int64
Field type: int64

Time

Full Usage: Time

Field type: AtDateTime
Field type: AtDateTime

Type something to start searching.