Header menu logo FSharp.ATProto

Sync Type

Updates the repo to a new state, without necessarily including that state on the firehose. Used to recover from broken commit streams, data loss incidents, or in situations where upstream host does not know recent state of the repository.

Record fields

Record Field Description

Blocks

Full Usage: Blocks

Field type: byte[]
Field type: byte[]

Did

Full Usage: Did

Field type: Did
Field type: Did

Rev

Full Usage: Rev

Field type: string
Field type: string

Seq

Full Usage: Seq

Field type: int64
Field type: int64

Time

Full Usage: Time

Field type: AtDateTime
Field type: AtDateTime

Type something to start searching.