Header menu logo FSharp.ATProto

ModerationAction Type

A type-safe union of moderation events that can be emitted via Ozone.emitEvent. Each case maps to the corresponding tools.ozone.moderation.defs#modEvent* type.

Union cases

Union case Description

Acknowledge comment

Full Usage: Acknowledge comment

Parameters:
    comment : string option

Acknowledge a report on a subject.

comment : string option

Comment(comment, sticky)

Full Usage: Comment(comment, sticky)

Parameters:
    comment : string
    sticky : bool option

Add a comment to a subject.

comment : string
sticky : bool option

Escalate comment

Full Usage: Escalate comment

Parameters:
    comment : string option

Escalate a subject for higher-level review.

comment : string option

Label(comment, createLabels, negateLabels)

Full Usage: Label(comment, createLabels, negateLabels)

Parameters:
    comment : string option
    createLabels : string list
    negateLabels : string list

Add or remove labels on a subject.

comment : string option
createLabels : string list
negateLabels : string list

Mute(comment, durationInHours)

Full Usage: Mute(comment, durationInHours)

Parameters:
    comment : string option
    durationInHours : int64

Mute incoming reports on a subject for a duration.

comment : string option
durationInHours : int64

MuteReporter(comment, durationInHours)

Full Usage: MuteReporter(comment, durationInHours)

Parameters:
    comment : string option
    durationInHours : int64 option

Mute incoming reports from a reporter account.

comment : string option
durationInHours : int64 option

ResolveAppeal comment

Full Usage: ResolveAppeal comment

Parameters:
    comment : string option

Resolve an appeal on a subject.

comment : string option

ReverseTakedown comment

Full Usage: ReverseTakedown comment

Parameters:
    comment : string option

Reverse a previous takedown action.

comment : string option

Tag(comment, add, remove)

Full Usage: Tag(comment, add, remove)

Parameters:
    comment : string option
    add : string list
    remove : string list

Add or remove tags on a subject.

comment : string option
add : string list
remove : string list

Takedown(comment, durationInHours)

Full Usage: Takedown(comment, durationInHours)

Parameters:
    comment : string option
    durationInHours : int64 option

Take down a subject permanently or temporarily.

comment : string option
durationInHours : int64 option

Unmute comment

Full Usage: Unmute comment

Parameters:
    comment : string option

Unmute incoming reports on a subject.

comment : string option

UnmuteReporter comment

Full Usage: UnmuteReporter comment

Parameters:
    comment : string option

Unmute incoming reports from a reporter account.

comment : string option

Instance members

Instance member Description

this.IsAcknowledge

Full Usage: this.IsAcknowledge

Returns: bool
Returns: bool

this.IsComment

Full Usage: this.IsComment

Returns: bool
Returns: bool

this.IsEscalate

Full Usage: this.IsEscalate

Returns: bool
Returns: bool

this.IsLabel

Full Usage: this.IsLabel

Returns: bool
Returns: bool

this.IsMute

Full Usage: this.IsMute

Returns: bool
Returns: bool

this.IsMuteReporter

Full Usage: this.IsMuteReporter

Returns: bool
Returns: bool

this.IsResolveAppeal

Full Usage: this.IsResolveAppeal

Returns: bool
Returns: bool

this.IsReverseTakedown

Full Usage: this.IsReverseTakedown

Returns: bool
Returns: bool

this.IsTag

Full Usage: this.IsTag

Returns: bool
Returns: bool

this.IsTakedown

Full Usage: this.IsTakedown

Returns: bool
Returns: bool

this.IsUnmute

Full Usage: this.IsUnmute

Returns: bool
Returns: bool

this.IsUnmuteReporter

Full Usage: this.IsUnmuteReporter

Returns: bool
Returns: bool

Type something to start searching.