PostRef Type
A reference to a specific version of a post record.
Contains both the AT-URI (identifying the record) and the CID (identifying the exact version).
Accepted by like, repost, and replyTo.
A reference to a specific version of a post record.
Contains both the AT-URI (identifying the record) and the CID (identifying the exact version).
Accepted by like, repost, and replyTo.