Header menu logo FSharp.ATProto

Defs Module

Types

Type Description

AccountEvent

Logs account status related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

AccountEventStatus

AccountHosting

AccountHostingStatus

AccountStats

Statistics about a particular account subject

AccountStrike

Strike information for an account

AgeAssuranceEvent

Age assurance info coming directly from users. Only works on DID subjects.

AgeAssuranceEventStatus

AgeAssuranceOverrideEvent

Age assurance status override by moderators. Only works on DID subjects.

AgeAssuranceOverrideEventStatus

BlobView

BlobViewDetailsUnion

CancelScheduledTakedownEvent

Logs cancellation of a scheduled takedown action for an account.

IdentityEvent

Logs identity related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

ImageDetails

ModEventAcknowledge

ModEventComment

Add a comment to a subject. An empty comment will clear any previously set sticky comment.

ModEventDivert

Divert a record's blobs to a 3rd party service for further scanning/tagging

ModEventEmail

Keep a log of outgoing email to a user

ModEventEscalate

ModEventLabel

Apply/Negate labels on a subject

ModEventMute

Mute incoming reports on a subject

ModEventMuteReporter

Mute incoming reports from an account

ModEventPriorityScore

Set priority score of the subject. Higher score means higher priority.

ModEventReport

Report a subject

ModEventResolveAppeal

Resolve appeal on a subject

ModEventReverseTakedown

Revert take down action on a subject

ModEventTag

Add/Remove a tag on a subject

ModEventTakedown

Take down a subject permanently or temporarily

ModEventTakedownTargetServicesItem

ModEventUnmute

Unmute action on a subject

ModEventUnmuteReporter

Unmute incoming reports from an account

ModEventView

ModEventViewDetail

ModEventViewDetailEventUnion

ModEventViewDetailSubjectUnion

ModEventViewEventUnion

ModEventViewSubjectUnion

ModTool

Moderation tool information for tracing the source of the action

Moderation

ModerationDetail

RecordEvent

Logs lifecycle event on a record subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

RecordEventOp

RecordHosting

RecordHostingStatus

RecordView

RecordViewDetail

RecordViewNotFound

RecordsStats

Statistics about a set of record subject items

RepoView

RepoViewDetail

RepoViewNotFound

ReporterStats

RevokeAccountCredentialsEvent

Account credentials revocation by moderators. Only works on DID subjects.

ScheduleTakedownEvent

Logs a scheduled takedown action for an account.

ScheduledActionView

View of a scheduled moderation action

ScheduledActionViewAction

ScheduledActionViewStatus

SubjectReviewState

SubjectStatusView

SubjectStatusViewAgeAssuranceState

SubjectStatusViewAgeAssuranceUpdatedBy

SubjectStatusViewHostingUnion

SubjectStatusViewSubjectUnion

SubjectView

Detailed view of a subject. For record subjects, the author's repo and profile will be returned.

SubjectViewProfileUnion

VideoDetails

Functions and values

Function or value Description

ReviewClosed

Full Usage: ReviewClosed

Returns: string
Returns: string

ReviewEscalated

Full Usage: ReviewEscalated

Returns: string
Returns: string

ReviewNone

Full Usage: ReviewNone

Returns: string
Returns: string

ReviewOpen

Full Usage: ReviewOpen

Returns: string
Returns: string

TimelineEventPlcCreate

Full Usage: TimelineEventPlcCreate

Returns: string
Returns: string

TimelineEventPlcOperation

Full Usage: TimelineEventPlcOperation

Returns: string
Returns: string

TimelineEventPlcTombstone

Full Usage: TimelineEventPlcTombstone

Returns: string
Returns: string

Type something to start searching.