Header menu logo FSharp.ATProto

AccountEvent Type

Logs account status related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

Record fields

Record Field Description

Active

Full Usage: Active

Field type: bool
Field type: bool

Comment

Full Usage: Comment

Field type: string option
Field type: string option

Status

Full Usage: Status

Field type: AccountEventStatus option
Field type: AccountEventStatus option

Timestamp

Full Usage: Timestamp

Field type: AtDateTime
Field type: AtDateTime

Type something to start searching.