Header menu logo FSharp.ATProto

PlcOperation Type

A PLC operation that creates, updates, or tombstones a DID document. Operations are signed with a rotation key and submitted to the PLC Directory.

Record fields

Record Field Description

AlsoKnownAs

Full Usage: AlsoKnownAs

Field type: string list

Alternative identifiers (e.g. ["at://handle.bsky.social"]). Empty for tombstone operations.

Field type: string list

Prev

Full Usage: Prev

Field type: string option

CID of the previous operation (dag-cbor, sha-256), or None for genesis.

Field type: string option

RotationKeys

Full Usage: RotationKeys

Field type: string list

Rotation keys (1-5 did:key values). Empty for tombstone operations.

Field type: string list

Services

Full Usage: Services

Field type: Map<string, PlcService>

Service endpoints keyed by service ID. Empty for tombstone operations.

Field type: Map<string, PlcService>

Sig

Full Usage: Sig

Field type: string option

Base64url-encoded ECDSA signature, or None if unsigned.

Field type: string option

Type

Full Usage: Type

Field type: PlcOperationType

The operation type.

Field type: PlcOperationType

VerificationMethods

Full Usage: VerificationMethods

Field type: Map<string, string>

Verification methods as a map of key ID to did:key value. Empty for tombstone operations.

Field type: Map<string, string>

Type something to start searching.