Header menu logo FSharp.ATProto

FSharp.ATProto.FeedGenerator Namespace

Type/Module Description

FeedAlgorithm

Helper module for creating feed algorithms from functions.

FeedDescription

Description of a single feed offered by this generator.

FeedGeneratorConfig

Configuration for the feed generator server.

FeedQuery

Query parameters from a getFeedSkeleton request.

FeedServer

GeneratorDescription

Response for describeFeedGenerator.

IFeedAlgorithm

Interface for implementing a custom feed algorithm.

SkeletonFeed

A feed skeleton response.

SkeletonItem

A single item in a feed skeleton response.

SkeletonReason

Reason for including a post in the skeleton (e.g., repost).

Type something to start searching.