Header menu logo FSharp.ATProto

FSharp.ATProto.Moderation Namespace

Type/Module Description

CustomLabelValueDef

Input for interpreting a custom label value definition from a labeler.

Label

A label applied to content or an account.

LabelBehaviors

Behaviors for a label across different subject types (account, profile, content).

LabelBlurs

What a label blurs in the UI.

LabelDefaultSetting

Default setting for a label when the user hasn't configured a preference.

LabelDefinition

Definition of a known label in the AT Protocol.

LabelFlag

Flags that modify label behavior.

Labels

LabelSeverity

Severity level of a label for UI display.

LabelTarget

Represents the target of a label application.

LabelVisibility

User's preferred visibility for a label.

Moderation

ModerationAction

The action a UI should take based on moderation.

ModerationBehavior

Behavior specification for a label in a specific context.

ModerationCause

A single cause for moderation action.

ModerationCauseSource

Source of a moderation cause.

ModerationCauseType

The type of moderation cause.

ModerationContext

Context in which moderation decisions are evaluated. Different contexts produce different actions for the same moderation cause.

ModerationDecision

The result of moderation evaluation, containing all causes and the resolved UI state.

ModerationPrefs

User preferences that influence moderation decisions.

MutedWord

A word or phrase the user has muted.

MutedWords

MutedWordTarget

Target for a muted word -- where should the match be checked.

Type something to start searching.