Header menu logo FSharp.ATProto

Moderation Module

Functions and values

Function or value Description

moderate prefs labels text tags languages isMuted isBlocked isBlockedBy isHiddenPost isMe target userDid context

Full Usage: moderate prefs labels text tags languages isMuted isBlocked isBlockedBy isHiddenPost isMe target userDid context

Parameters:
    prefs : ModerationPrefs
    labels : Label list
    text : string option
    tags : string list
    languages : string list
    isMuted : bool
    isBlocked : bool
    isBlockedBy : bool
    isHiddenPost : bool
    isMe : bool
    target : LabelTarget
    userDid : string option
    context : ModerationContext

Returns: ModerationDecision

Full moderation evaluation combining labels, muted words, mute status, block status, and hidden post status into a single decision for a given context.

prefs : ModerationPrefs
labels : Label list
text : string option
tags : string list
languages : string list
isMuted : bool
isBlocked : bool
isBlockedBy : bool
isHiddenPost : bool
isMe : bool
target : LabelTarget
userDid : string option
context : ModerationContext
Returns: ModerationDecision

moderateContent prefs labels context

Full Usage: moderateContent prefs labels context

Parameters:
Returns: ModerationDecision

Simplified moderation for content with just labels.

prefs : ModerationPrefs
labels : Label list
context : ModerationContext
Returns: ModerationDecision

moderateFeedGenerator prefs labels context

Full Usage: moderateFeedGenerator prefs labels context

Parameters:
Returns: ModerationDecision

Simplified moderation for a feed generator. Feed generators are moderated as content, checking labels applied to the feed itself.

prefs : ModerationPrefs
labels : Label list
context : ModerationContext
Returns: ModerationDecision

moderateLabels prefs labels target userDid

Full Usage: moderateLabels prefs labels target userDid

Parameters:
Returns: ModerationCause list

Evaluate labels against moderation preferences and produce causes.

prefs : ModerationPrefs
labels : Label list
target : LabelTarget
userDid : string option
Returns: ModerationCause list

moderateLabelsWithCustom prefs labels target userDid customLabelMap

Full Usage: moderateLabelsWithCustom prefs labels target userDid customLabelMap

Parameters:
Returns: ModerationCause list

Evaluate labels using a custom label map (supports custom labeler definitions). The label map is created via Labels.createLabelMap.

prefs : ModerationPrefs
labels : Label list
target : LabelTarget
userDid : string option
customLabelMap : Map<(string * string), LabelDefinition>
Returns: ModerationCause list

moderateMutedWords mutedWords text tags languages

Full Usage: moderateMutedWords mutedWords text tags languages

Parameters:
    mutedWords : MutedWord list
    text : string
    tags : string list
    languages : string list

Returns: ModerationCause list

Evaluate muted words against text and tags.

mutedWords : MutedWord list
text : string
tags : string list
languages : string list
Returns: ModerationCause list

moderateNotification prefs labels isMuted isBlocked isBlockedBy

Full Usage: moderateNotification prefs labels isMuted isBlocked isBlockedBy

Parameters:
Returns: ModerationDecision

Simplified moderation for a notification. Notifications are moderated as content in a list context, primarily checking labels on the notification author and mute/block status.

prefs : ModerationPrefs
labels : Label list
isMuted : bool
isBlocked : bool
isBlockedBy : bool
Returns: ModerationDecision

moderatePost prefs labels text tags languages isHiddenPost isMe userDid context

Full Usage: moderatePost prefs labels text tags languages isHiddenPost isMe userDid context

Parameters:
    prefs : ModerationPrefs
    labels : Label list
    text : string
    tags : string list
    languages : string list
    isHiddenPost : bool
    isMe : bool
    userDid : string option
    context : ModerationContext

Returns: ModerationDecision

Simplified moderation for a post with text.

prefs : ModerationPrefs
labels : Label list
text : string
tags : string list
languages : string list
isHiddenPost : bool
isMe : bool
userDid : string option
context : ModerationContext
Returns: ModerationDecision

moderateProfile prefs labels isMuted isBlocked isBlockedBy isMe context

Full Usage: moderateProfile prefs labels isMuted isBlocked isBlockedBy isMe context

Parameters:
Returns: ModerationDecision

Simplified moderation for a profile/account.

prefs : ModerationPrefs
labels : Label list
isMuted : bool
isBlocked : bool
isBlockedBy : bool
isMe : bool
context : ModerationContext
Returns: ModerationDecision

moderateUserList prefs labels context

Full Usage: moderateUserList prefs labels context

Parameters:
Returns: ModerationDecision

Simplified moderation for a user list. User lists are moderated as content, checking labels applied to the list.

prefs : ModerationPrefs
labels : Label list
context : ModerationContext
Returns: ModerationDecision

resolveLabels labels

Full Usage: resolveLabels labels

Parameters:
Returns: Label list

Resolve negation labels -- a label with Neg=true cancels out a previous non-negation label with the same Val from the same Src.

labels : Label list
Returns: Label list

Type something to start searching.