Header menu logo FSharp.ATProto

ModerationDecision Type

The result of moderation evaluation, containing all causes and the resolved UI state.

Record fields

Record Field Description

Alert

Full Usage: Alert

Field type: bool

Whether any alert causes are present

Field type: bool

Blur

Full Usage: Blur

Field type: bool

Whether any blur causes are present

Field type: bool

Causes

Full Usage: Causes

Field type: ModerationCause list

All moderation causes that apply, sorted by priority

Field type: ModerationCause list

Filter

Full Usage: Filter

Field type: bool

Whether any filter causes are present

Field type: bool

Inform

Full Usage: Inform

Field type: bool

Whether any inform causes are present

Field type: bool

NoOverride

Full Usage: NoOverride

Field type: bool

Whether the blur cannot be overridden by the user

Field type: bool

Instance members

Instance member Description

this.Action

Full Usage: this.Action

Returns: ModerationAction

The primary (highest-priority) action to take.

Returns: ModerationAction

this.PrimaryCause

Full Usage: this.PrimaryCause

Returns: ModerationCause option

The primary (highest-priority) cause, if any.

Returns: ModerationCause option

Static members

Static member Description

ModerationDecision.None

Full Usage: ModerationDecision.None

Returns: ModerationDecision

A decision with no moderation action.

Returns: ModerationDecision

Type something to start searching.