Header menu logo FSharp.ATProto

MutedWords Module

Functions and values

Function or value Description

hasMutedWord mutedWords text tags languages

Full Usage: hasMutedWord mutedWords text tags languages

Parameters:
    mutedWords : MutedWord list
    text : string
    tags : string list
    languages : string list

Returns: bool

Check whether any of the muted words match the given text and tags. Returns true if any muted word matches.

mutedWords : MutedWord list
text : string
tags : string list
languages : string list
Returns: bool

isExpired mutedWord

Full Usage: isExpired mutedWord

Parameters:
Returns: bool

Check whether a muted word has expired.

mutedWord : MutedWord
Returns: bool

matchesMutedWord mutedWord text tags languages

Full Usage: matchesMutedWord mutedWord text tags languages

Parameters:
    mutedWord : MutedWord
    text : string
    tags : string list
    languages : string list

Returns: bool

Check whether a single muted word matches the given text content. The text and tags are checked based on the muted word's target configuration. Returns true if the muted word matches.

mutedWord : MutedWord
text : string
tags : string list
languages : string list
Returns: bool

Type something to start searching.