ClientCache Type
A simple cache for client metadata with configurable TTL.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.GetOrFetch
Parameters:
HttpClient
clientId : string
Returns: Task<Result<ClientMetadata, OAuthServerError>>
|
Get cached client metadata or fetch it from the client_id URL.
|