Header menu logo FSharp.ATProto

FSharp.ATProto.Pds Namespace

Type/Module Description

AccountCreatedEvent

Fired when a new account is created on the PDS.

Pds

Personal Data Server for the AT Protocol.

PdsAccount

PdsBuilder (Module)

PdsBuilder (Type)

PdsState

RecordCreatedEvent

Fired when a record is created in a repository.

RecordDeletedEvent

Fired when a record is deleted from a repository.

RunningPds

A running PDS instance that can be interacted with programmatically.

SessionInfo

StoredRecord

Type something to start searching.