Header menu logo FSharp.ATProto

FSharp.ATProto.Streaming Namespace

Type/Module Description

AccountInfo

Account status change information from a Jetstream event.

CarFile

A parsed CAR v1 file.

CarParser

Parser for CAR v1 (Content Addressable aRchive) files used by the AT Protocol firehose.

CommitInfo

Details of a repository commit from a Jetstream event.

CommitOperation

The operation type within a Jetstream commit event.

Firehose

FirehoseAccount

A firehose account status event.

FirehoseCommit

A firehose commit event with repository operations and CAR block data.

FirehoseEvent

A parsed firehose event from com.atproto.sync.subscribeRepos.

FirehoseIdentity

A firehose identity event.

FirehoseInfo

An informational firehose message (e.g., OutdatedCursor).

FirehoseOptions

Options for configuring a firehose subscription.

IdentityInfo

Identity change information from a Jetstream event.

Jetstream

JetstreamEvent

A parsed Jetstream event.

JetstreamOptions

Options for configuring a Jetstream subscription.

RepoOp

A record-level operation within a firehose commit.

StreamError

Errors that can occur during Jetstream event streaming.

Type something to start searching.