Jetstream Module
Functions and values
| Function or value |
Description
|
|
|
|
Default Jetstream options pointing at the US-East relay.
|
|
Parse a raw Jetstream JSON message into a JetstreamEvent.
|
Full Usage:
subscribe options ct
Parameters:
JetstreamOptions
ct : CancellationToken
Returns: IAsyncEnumerable<Result<JetstreamEvent, StreamError>>
|
Subscribe to a Jetstream relay. Returns an IAsyncEnumerable that yields events until the connection closes or the CancellationToken is triggered. On disconnect the final element will be Error Closed.
|