Header menu logo FSharp.ATProto

AtDateTime Type

An AT Protocol datetime string, a strict subset of RFC 3339 / ISO 8601. Format: YYYY-MM-DDTHH:MM:SS[.fractional](Z|+HH:MM|-HH:MM).

AT Protocol datetimes have stricter requirements than general RFC 3339: exactly 4-digit year, uppercase T separator, uppercase Z for UTC, seconds are required, and the offset -00:00 is not allowed. See the AT Protocol specification: https://atproto.com/specs/lexicon#datetime

Type something to start searching.