Header menu logo FSharp.ATProto

Cid Module

Functions for creating, validating, and extracting data from Cid values.

Functions and values

Function or value Description

parse s

Full Usage: parse s

Parameters:
    s : string - A CID string of 8-256 alphanumeric characters (plus +, /, =). CIDv0 strings (starting with Qmb) are not supported.

Returns: Result<Cid, string> Ok with a validated Cid, or Error with a message describing the validation failure. Validation failures include: null input, CIDv0 format, or invalid syntax.

Parse and validate a CID string.

s : string

A CID string of 8-256 alphanumeric characters (plus +, /, =). CIDv0 strings (starting with Qmb) are not supported.

Returns: Result<Cid, string>

Ok with a validated Cid, or Error with a message describing the validation failure. Validation failures include: null input, CIDv0 format, or invalid syntax.

value arg1

Full Usage: value arg1

Parameters:
Returns: string The CID string in its base-encoded form.

Extract the string representation of a CID.

arg0 : Cid
Returns: string

The CID string in its base-encoded form.

Type something to start searching.