Header menu logo FSharp.ATProto

Handle Type

A handle (domain name) used as a human-readable identifier in the AT Protocol. Handles are DNS-based names (e.g. my-handle.bsky.social) that resolve to a Did. They must be valid domain names with at least two segments and a maximum length of 253 characters.

See the AT Protocol specification: https://atproto.com/specs/handle

Type something to start searching.