Header menu logo FSharp.ATProto

Language Type

A BCP 47 language tag used to identify the language of content in the AT Protocol. Examples include "en", "pt-BR", "zh-Hans", and grandfathered tags like "i-default".

This is a simplified/naive parser that validates the basic structure of BCP 47 tags: a 2-3 letter primary subtag (or the special prefix "i" for grandfathered tags), optionally followed by hyphen-separated alphanumeric subtags. See https://www.rfc-editor.org/rfc/rfc5646.html for the full BCP 47 specification.

Type something to start searching.