Header menu logo FSharp.ATProto

Nsid Type

A Namespaced Identifier (NSID) used to reference Lexicon schemas in the AT Protocol. NSIDs follow the pattern authority.name where the authority is a reversed domain name and the name identifies the specific schema (e.g. app.bsky.feed.post). Maximum length is 317 characters.

See the AT Protocol specification: https://atproto.com/specs/nsid

Type something to start searching.