Header menu logo FSharp.ATProto

Tid Type

A timestamp-based identifier (TID) used as record keys in the AT Protocol. TIDs are 13-character strings encoded in a base32-sortable format that embeds a microsecond timestamp and a clock identifier. They are lexicographically sortable by creation time.

See the AT Protocol specification: https://atproto.com/specs/record-key The first character is restricted to the range [234567abcdefghij] to ensure the encoded timestamp fits in a 64-bit integer.

Type something to start searching.