Header menu logo FSharp.ATProto

Uri Type

A general URI as defined by RFC 3986, used in the AT Protocol for links and references. Must have a valid scheme (starting with a letter, followed by letters, digits, +, -, or .) followed by : and a non-empty scheme-specific part with no whitespace. Maximum length is 8192 characters.

This performs basic syntactic validation only. Valid scheme examples include https, dns, at, did, and content-type. See https://www.rfc-editor.org/rfc/rfc3986 for the full URI specification.

Type something to start searching.