Header menu logo FSharp.ATProto

XrpcServerConfig Type

Configuration for the XRPC server.

Record fields

Record Field Description

Endpoints

Full Usage: Endpoints

Field type: XrpcEndpoint list

Registered XRPC endpoints.

Field type: XrpcEndpoint list

GlobalRateLimit

Full Usage: GlobalRateLimit

Field type: RateLimitConfig option

Global rate limit applied to all endpoints that don't have a per-endpoint limit.

Field type: RateLimitConfig option

JsonOptions

Full Usage: JsonOptions

Field type: JsonSerializerOptions

JSON serializer options for request/response bodies.

Field type: JsonSerializerOptions

VerifyToken

Full Usage: VerifyToken

Field type: (string -> Task<Result<ClaimsPrincipal, string>>) option

Optional token verification function for auth. Receives the bearer token string and returns a ClaimsPrincipal on success.

Field type: (string -> Task<Result<ClaimsPrincipal, string>>) option

Type something to start searching.