Defs Module
Types
| Type | Description |
|
|
|
|
If set, an active progress guide. Once completed, can be set to undefined. Should have unspecced fields tracking progress. |
|
|
A grab bag of state that's specific to the bsky.app program. Third-party apps shouldn't use this. |
|
|
|
|
|
|
|
|
Read-only preference containing value(s) inferred from the user's declared birthdate. Absence of this preference object in the response indicates that the user has not made a declaration. |
|
|
|
|
|
|
|
|
|
|
|
The subject's followers whom you also follow |
|
|
|
|
|
|
|
|
Preferences for live events. |
|
|
A word that the account owner has muted. |
|
|
|
|
|
|
|
|
|
|
|
A new user experiences (NUX) storage object |
|
|
|
|
|
Default post interaction settings for the account. These values should be applied as default values when creating new posts. These refs should mirror the threadgate and postgate records exactly. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
An optional embed associated with the status. |
|
|
|
|
|
|
|
|
|
|
|
Preferences for how verified accounts appear in the app. |
|
|
Represents the verification information about the user this object is attached to. |
|
|
|
|
|
|
|
|
An individual verification for an associated subject. |
|
|
Metadata about the requesting account's relationship with the subject account. Only has meaningful content for authed requests. |