DeclaredAgePref Type
Read-only preference containing value(s) inferred from the user's declared birthdate. Absence of this preference object in the response indicates that the user has not made a declaration.
Record fields
| Record Field |
Description
|
Full Usage:
IsOverAge13
Field type: bool option
|
|
Full Usage:
IsOverAge16
Field type: bool option
|
|
Full Usage:
IsOverAge18
Field type: bool option
|
|