PostInteractionSettingsPref Type
Default post interaction settings for the account. These values should be applied as default values when creating new posts. These refs should mirror the threadgate and postgate records exactly.
Record fields
| Record Field |
Description
|
Full Usage:
PostgateEmbeddingRules
Field type: PostInteractionSettingsPrefPostgateEmbeddingRulesItem list option
|
|
Full Usage:
ThreadgateAllowRules
Field type: PostInteractionSettingsPrefThreadgateAllowRulesItem list option
|
|