Defs Module
Types
| Type | Description |
|
|
|
|
|
|
|
The Age Assurance configuration for a specific region. |
|
|
Age Assurance rule that applies by default. |
|
|
Age Assurance rule that applies if the account is equal-to or newer than a certain date. |
|
|
Age Assurance rule that applies if the account is older than a certain date. |
|
|
Age Assurance rule that applies if the user has been assured to be equal-to or over a certain age. |
|
|
Age Assurance rule that applies if the user has been assured to be under a certain age. |
|
|
Age Assurance rule that applies if the user has declared themselves equal-to or over a certain age. |
|
|
Age Assurance rule that applies if the user has declared themselves under a certain age. |
|
|
|
|
|
Object used to store Age Assurance data in stash. |
|
|
|
|
|
|
|
|
The user's computed Age Assurance state. |
|
|
Additional metadata needed to compute Age Assurance state client-side. |
|
|
|