Defs Module
Types
| Type | Description |
|
Associates a profile with the positional index of the contact import input in the call to `app.bsky.contact.importContacts`, so clients can know which phone caused a particular match. |
|
|
A stash object to be sent via bsync representing a notification to be created. |
|
|
|