MatchAndContactIndex Type
Associates a profile with the positional index of the contact import input in the call to `app.bsky.contact.importContacts`, so clients can know which phone caused a particular match.
Record fields
| Record Field |
Description
|
Full Usage:
ContactIndex
Field type: int64
|
|
|
|