Postgate Module
Types
| Type | Description |
|
|
|
|
Record defining interaction rules for a post. The record key (rkey) of the postgate record must match the record key of the post, and that record must be in the same repository. |
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
TypeId
Returns: string
|
|