Threadgate Type
Record defining interaction gating rules for a thread (aka, reply controls). The record key (rkey) of the threadgate record must match the record key of the thread's root post, and that record must be in the same repository.
Record fields
| Record Field |
Description
|
|
|
|
|
|
|
|