Verification Module
Types
| Type | Description |
|
Record declaring a verification relationship between two accounts. Verifications are only considered valid by an app if issued by an account the app considers trusted. |
Functions and values
| Function or value |
Description
|
Full Usage:
TypeId
Returns: string
|
|