Defs Module
Types
| Type | Description |
|
Object used to store age assurance data in stash. |
|
|
|
|
|
The computed state of the age assurance process, returned to the user in question on certain authenticated requests. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|