AgeAssuranceState Type
The computed state of the age assurance process, returned to the user in question on certain authenticated requests.
Record fields
| Record Field |
Description
|
|
|
|
|
The computed state of the age assurance process, returned to the user in question on certain authenticated requests.
| Record Field |
Description
|
|
|
|
|