Defs Module
Types
| Type | Description |
|
Metadata tag on an atproto resource (eg, repo or record). |
|
|
|
|
|
Declares a label value and its expected interpretations and behaviors. |
|
|
|
|
|
|
|
|
|
|
|
Strings which describe the label in the UI, localized into a specific language. |
|
|
Metadata tag on an atproto record, published by the author within the record. Note that schemas should use #selfLabels, not #selfLabel. |
|
|
Metadata tags on an atproto record, published by the author within the record. |