Schema Module
Types
| Type | Description |
|
Representation of Lexicon schemas themselves, when published as atproto records. Note that the schema language is not defined in Lexicon; this meta schema currently only includes a single version field ('lexicon'). See the atproto specifications for description of the other expected top-level fields ('id', 'defs', etc). |
Functions and values
| Function or value |
Description
|
Full Usage:
TypeId
Returns: string
|
|