Schema Type
Representation of Lexicon schemas themselves, when published as atproto records. Note that the schema language is not defined in Lexicon; this meta schema currently only includes a single version field ('lexicon'). See the atproto specifications for description of the other expected top-level fields ('id', 'defs', etc).
Record fields
| Record Field |
Description
|
Full Usage:
Lexicon
Field type: int64
|
|