SubscribeRepos Module
Types and nested modules
| Type/Module | Description |
|
|
|
|
Represents a change to an account's status on a host (eg, PDS or Relay). The semantics of this event are that the status is at the host which emitted the event, not necessarily that at the currently active PDS. Eg, a Relay takedown would emit a takedown with active=false, even if the PDS is still active. |
|
|
|
|
|
Represents an update of repository state. Note that empty commits are allowed, which include no repo data changes, but an update to rev and signature. |
|
|
Represents a change to an account's identity. Could be an updated handle, signing key, or pds hosting endpoint. Serves as a prod to all downstream services to refresh their identity cache. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
A repo operation, ie a mutation of a single record. |
|
|
|
|
|
Updates the repo to a new state, without necessarily including that state on the firehose. Used to recover from broken commit streams, data loss incidents, or in situations where upstream host does not know recent state of the repository. |
Functions and values
| Function or value |
Description
|
Full Usage:
TypeId
Returns: string
|
|