Account Type
Represents a change to an account's status on a host (eg, PDS or Relay). The semantics of this event are that the status is at the host which emitted the event, not necessarily that at the currently active PDS. Eg, a Relay takedown would emit a takedown with active=false, even if the PDS is still active.
Record fields
| Record Field |
Description
|
Full Usage:
Active
Field type: bool
|
|
|
|
Full Usage:
Seq
Field type: int64
|
|
|
|
|
|