Commit Type
Represents an update of repository state. Note that empty commits are allowed, which include no repo data changes, but an update to rev and signature.
Record fields
| Record Field |
Description
|
|
|
Full Usage:
Blocks
Field type: byte[]
|
|
|
|
|
|
|
|
Full Usage:
Rebase
Field type: bool
|
|
|
|
|
|
Full Usage:
Seq
Field type: int64
|
|
|
|
|
|
Full Usage:
TooBig
Field type: bool
|
|