Sync Type
Updates the repo to a new state, without necessarily including that state on the firehose. Used to recover from broken commit streams, data loss incidents, or in situations where upstream host does not know recent state of the repository.
Record fields
| Record Field |
Description
|
Full Usage:
Blocks
Field type: byte[]
|
|
|
|
Full Usage:
Rev
Field type: string
|
|
Full Usage:
Seq
Field type: int64
|
|
|
|