ModerationAction Type
A type-safe union of moderation events that can be emitted via Ozone.emitEvent.
Each case maps to the corresponding tools.ozone.moderation.defs#modEvent* type.
Union cases
| Union case |
Description
|
Full Usage:
Acknowledge comment
Parameters:
string option
|
Acknowledge a report on a subject.
|
Full Usage:
Comment(comment, sticky)
Parameters:
string
sticky : bool option
|
Add a comment to a subject.
|
Full Usage:
Escalate comment
Parameters:
string option
|
Escalate a subject for higher-level review.
|
Full Usage:
Label(comment, createLabels, negateLabels)
Parameters:
string option
createLabels : string list
negateLabels : string list
|
Add or remove labels on a subject.
|
Full Usage:
Mute(comment, durationInHours)
Parameters:
string option
durationInHours : int64
|
Mute incoming reports on a subject for a duration.
|
Full Usage:
MuteReporter(comment, durationInHours)
Parameters:
string option
durationInHours : int64 option
|
Mute incoming reports from a reporter account.
|
Full Usage:
ResolveAppeal comment
Parameters:
string option
|
Resolve an appeal on a subject.
|
Full Usage:
ReverseTakedown comment
Parameters:
string option
|
Reverse a previous takedown action.
|
Full Usage:
Tag(comment, add, remove)
Parameters:
string option
add : string list
remove : string list
|
Add or remove tags on a subject.
|
Full Usage:
Takedown(comment, durationInHours)
Parameters:
string option
durationInHours : int64 option
|
Take down a subject permanently or temporarily.
|
Full Usage:
Unmute comment
Parameters:
string option
|
Unmute incoming reports on a subject.
|
Full Usage:
UnmuteReporter comment
Parameters:
string option
|
Unmute incoming reports from a reporter account.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAcknowledge
Returns: bool
|
|
Full Usage:
this.IsComment
Returns: bool
|
|
Full Usage:
this.IsEscalate
Returns: bool
|
|
Full Usage:
this.IsLabel
Returns: bool
|
|
Full Usage:
this.IsMute
Returns: bool
|
|
Full Usage:
this.IsMuteReporter
Returns: bool
|
|
Full Usage:
this.IsResolveAppeal
Returns: bool
|
|
Full Usage:
this.IsReverseTakedown
Returns: bool
|
|
Full Usage:
this.IsTag
Returns: bool
|
|
Full Usage:
this.IsTakedown
Returns: bool
|
|
Full Usage:
this.IsUnmute
Returns: bool
|
|
Full Usage:
this.IsUnmuteReporter
Returns: bool
|
|