TestFactory Type
Factory methods for creating domain objects with sensible defaults. Useful for testing consumers of the library without needing a live API. All parameters are optional; unspecified fields use deterministic default values.
Static members
| Static member |
Description
|
|
|
Full Usage:
TestFactory.FeedItem(?post, ?reason, ?replyParent)
Parameters:
TimelinePost
?reason : FeedReason
?replyParent : TimelinePost
Returns: FeedItem
|
Create a FeedItem wrapping a TimelinePost with no feed reason.
|
|
|
|
|
Full Usage:
TestFactory.Notification(?recordUri, ?author, ?content, ?isRead, ?indexedAt)
Parameters:
AtUri
?author : ProfileSummary
?content : NotificationContent
?isRead : bool
?indexedAt : DateTimeOffset
Returns: Notification
|
Create a Notification with sensible defaults.
|
|
|
Full Usage:
TestFactory.Profile(?did, ?handle, ?displayName, ?description, ?avatar, ?banner, ?postsCount, ?followersCount, ?followsCount, ?isFollowing, ?isFollowedBy, ?isBlocking, ?isBlockedBy, ?isMuted)
Parameters:
Did
?handle : Handle
?displayName : string
?description : string
?avatar : string
?banner : string
?postsCount : int64
?followersCount : int64
?followsCount : int64
?isFollowing : bool
?isFollowedBy : bool
?isBlocking : bool
?isBlockedBy : bool
?isMuted : bool
Returns: Profile
|
Create a Profile with sensible defaults. Override any field by passing named parameters.
|
Full Usage:
TestFactory.ProfileSummary(?did, ?handle, ?displayName, ?avatar)
Parameters: Returns: ProfileSummary
|
Create a ProfileSummary with sensible defaults. Override any field by passing named parameters.
|
|
|
Full Usage:
TestFactory.TimelinePost(?uri, ?cid, ?author, ?text, ?facets, ?likeCount, ?repostCount, ?replyCount, ?quoteCount, ?indexedAt, ?isLiked, ?isReposted, ?isBookmarked)
Parameters:
AtUri
?cid : Cid
?author : ProfileSummary
?text : string
?facets : Facet list
?likeCount : int64
?repostCount : int64
?replyCount : int64
?quoteCount : int64
?indexedAt : DateTimeOffset
?isLiked : bool
?isReposted : bool
?isBookmarked : bool
Returns: TimelinePost
|
Create a TimelinePost with sensible defaults. Override any field by passing named parameters.
|