Defs Module
Types
| Type | Description |
|
Logs account status related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking. |
|
|
|
|
|
|
|
|
|
|
|
Statistics about a particular account subject |
|
|
Strike information for an account |
|
|
Age assurance info coming directly from users. Only works on DID subjects. |
|
|
|
|
|
Age assurance status override by moderators. Only works on DID subjects. |
|
|
|
|
|
|
|
|
|
|
|
Logs cancellation of a scheduled takedown action for an account. |
|
|
Logs identity related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking. |
|
|
|
|
|
|
|
|
Add a comment to a subject. An empty comment will clear any previously set sticky comment. |
|
|
Divert a record's blobs to a 3rd party service for further scanning/tagging |
|
|
Keep a log of outgoing email to a user |
|
|
|
|
|
Apply/Negate labels on a subject |
|
|
Mute incoming reports on a subject |
|
|
Mute incoming reports from an account |
|
|
Set priority score of the subject. Higher score means higher priority. |
|
|
Report a subject |
|
|
Resolve appeal on a subject |
|
|
Revert take down action on a subject |
|
|
Add/Remove a tag on a subject |
|
|
Take down a subject permanently or temporarily |
|
|
|
|
|
Unmute action on a subject |
|
|
Unmute incoming reports from an account |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Moderation tool information for tracing the source of the action |
|
|
|
|
|
|
|
|
Logs lifecycle event on a record subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Statistics about a set of record subject items |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Account credentials revocation by moderators. Only works on DID subjects. |
|
|
Logs a scheduled takedown action for an account. |
|
|
View of a scheduled moderation action |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Detailed view of a subject. For record subjects, the author's repo and profile will be returned. |
|
|
|
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
ReviewClosed
Returns: string
|
|
Full Usage:
ReviewEscalated
Returns: string
|
|
Full Usage:
ReviewNone
Returns: string
|
|
Full Usage:
ReviewOpen
Returns: string
|
|
Full Usage:
TimelineEventPlcCreate
Returns: string
|
|
Full Usage:
TimelineEventPlcOperation
Returns: string
|
|
Full Usage:
TimelineEventPlcTombstone
Returns: string
|
|