PlcOperation Type
A PLC operation that creates, updates, or tombstones a DID document. Operations are signed with a rotation key and submitted to the PLC Directory.
Record fields
| Record Field |
Description
|
Full Usage:
AlsoKnownAs
Field type: string list
|
Alternative identifiers (e.g.
|
Full Usage:
Prev
Field type: string option
|
CID of the previous operation (dag-cbor, sha-256), or
|
Full Usage:
RotationKeys
Field type: string list
|
Rotation keys (1-5
|
|
Service endpoints keyed by service ID. Empty for tombstone operations.
|
Full Usage:
Sig
Field type: string option
|
Base64url-encoded ECDSA signature, or
|
|
The operation type.
|
|
Verification methods as a map of key ID to
|