FSharp.ATProto.FeedGenerator Namespace
| Type/Module | Description |
|
Helper module for creating feed algorithms from functions. |
|
|
Description of a single feed offered by this generator. |
|
|
Configuration for the feed generator server. |
|
|
Query parameters from a getFeedSkeleton request. |
|
|
|
|
|
Response for describeFeedGenerator. |
|
|
Interface for implementing a custom feed algorithm. |
|
|
A feed skeleton response. |
|
|
A single item in a feed skeleton response. |
|
|
Reason for including a post in the skeleton (e.g., repost). |