ModerationDecision Type
The result of moderation evaluation, containing all causes and the resolved UI state.
Record fields
| Record Field |
Description
|
Full Usage:
Alert
Field type: bool
|
Whether any alert causes are present
|
Full Usage:
Blur
Field type: bool
|
Whether any blur causes are present
|
|
All moderation causes that apply, sorted by priority
|
Full Usage:
Filter
Field type: bool
|
Whether any filter causes are present
|
Full Usage:
Inform
Field type: bool
|
Whether any inform causes are present
|
Full Usage:
NoOverride
Field type: bool
|
Whether the blur cannot be overridden by the user
|
Instance members
| Instance member |
Description
|
|
The primary (highest-priority) action to take.
|
|
The primary (highest-priority) cause, if any.
|
Static members
| Static member |
Description
|
|
A decision with no moderation action.
|