MutedWords Module
Functions and values
| Function or value |
Description
|
Full Usage:
hasMutedWord mutedWords text tags languages
Parameters:
MutedWord list
text : string
tags : string list
languages : string list
Returns: bool
|
Check whether any of the muted words match the given text and tags. Returns true if any muted word matches.
|
|
|
Full Usage:
matchesMutedWord mutedWord text tags languages
Parameters:
MutedWord
text : string
tags : string list
languages : string list
Returns: bool
|
Check whether a single muted word matches the given text content. The text and tags are checked based on the muted word's target configuration. Returns true if the muted word matches.
|