FSharp.ATProto.Pds Namespace
| Type/Module | Description |
|
Fired when a new account is created on the PDS. |
|
|
Personal Data Server for the AT Protocol. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Fired when a record is created in a repository. |
|
|
Fired when a record is deleted from a repository. |
|
|
A running PDS instance that can be interacted with programmatically. |
|
|
|
|
|
|