FSharp.ATProto.Streaming Namespace
| Type/Module | Description |
|
Account status change information from a Jetstream event. |
|
|
A parsed CAR v1 file. |
|
|
Parser for CAR v1 (Content Addressable aRchive) files used by the AT Protocol firehose. |
|
|
Details of a repository commit from a Jetstream event. |
|
|
The operation type within a Jetstream commit event. |
|
|
|
|
|
A firehose account status event. |
|
|
A firehose commit event with repository operations and CAR block data. |
|
|
A parsed firehose event from com.atproto.sync.subscribeRepos. |
|
|
A firehose identity event. |
|
|
An informational firehose message (e.g., OutdatedCursor). |
|
|
Options for configuring a firehose subscription. |
|
|
Identity change information from a Jetstream event. |
|
|
|
|
|
A parsed Jetstream event. |
|
|
Options for configuring a Jetstream subscription. |
|
|
A record-level operation within a firehose commit. |
|
|
Errors that can occur during Jetstream event streaming. |