Firehose Module
Functions and values
| Function or value |
Description
|
|
|
|
Default firehose options pointing at the main Bluesky relay.
|
Full Usage:
parseFrame data count
Parameters:
byte[]
count : int
Returns: Result<FirehoseEvent, StreamError>
|
Parse a raw firehose WebSocket binary frame into a FirehoseEvent.
|
Full Usage:
subscribe options ct
Parameters:
FirehoseOptions
ct : CancellationToken
Returns: IAsyncEnumerable<Result<FirehoseEvent, StreamError>>
|
Subscribe to the AT Protocol firehose. Returns an IAsyncEnumerable that yields parsed events until the connection closes or the CancellationToken is triggered.
|