AtIdentifier Module
Functions for creating, validating, and extracting data from AtIdentifier values.
Functions and values
| Function or value |
Description
|
Full Usage:
parse s
Parameters:
string
-
A string that is either a valid DID (e.g. "did:plc:z72i7hdynmk6r22z27h6tvur")
or a valid handle (e.g. "my-handle.bsky.social").
Returns: Result<AtIdentifier, string>
Ok with an AtIdentifier wrapping either AtDid or AtHandle,
or Error if the string is neither a valid DID nor a valid handle.
|
Parse a string as an AT identifier, trying DID first and then handle.
|
Full Usage:
value _arg1
Parameters:
AtIdentifier
Returns: string
The identifier string, whether it is a DID or handle.
|
Extract the string representation of an AT identifier.
|