XrpcServerConfig Type
Configuration for the XRPC server.
Record fields
| Record Field |
Description
|
|
Registered XRPC endpoints.
|
|
Global rate limit applied to all endpoints that don't have a per-endpoint limit.
|
|
JSON serializer options for request/response bodies.
|
|
Optional token verification function for auth. Receives the bearer token string and returns a ClaimsPrincipal on success.
|